Documentation
¶
Index ¶
- Constants
- func ContextAddr(ctx context.Context) string
- func ContextHandlerMiddleware(ctx context.Context) []string
- func ContextHandlerPrefix(ctx context.Context) string
- func ContextHasPluginParent(ctx context.Context, v string) bool
- func ContextParams(ctx context.Context) []string
- func ContextPath(ctx context.Context) string
- func ContextPluginName(ctx context.Context) string
- func ContextUser(ctx context.Context) string
- func ContextWithAddr(parent context.Context, addr string) context.Context
- func ContextWithAuth(parent context.Context, user string, auth map[string]interface{}) context.Context
- func ContextWithHandler(parent context.Context, handler config.Handler) context.Context
- func ContextWithPathParams(parent context.Context, path string, params []string) context.Context
- func ContextWithPluginName(ctx context.Context, name string) context.Context
- func ContextWithPrefix(ctx context.Context, prefix string) context.Context
- func DumpContext(ctx context.Context) string
- func GetPluginName(path string) (string, error)
- func NewProvider(parent context.Context, basepath string, cfg *config.Config) (*provider, error)
- func PluginPath(basepath, path string) string
- type PluginUsageFunc
Constants ¶
const (
PluginFileExt = ".plugin"
)
Variables ¶
This section is empty.
Functions ¶
func ContextAddr ¶ added in v1.0.15
func ContextHandlerMiddleware ¶ added in v1.0.15
func ContextHandlerPrefix ¶ added in v1.0.15
func ContextHasPluginParent ¶ added in v1.0.15
func ContextParams ¶ added in v1.0.15
func ContextPath ¶ added in v1.0.15
func ContextPluginName ¶ added in v1.0.15
func ContextUser ¶ added in v1.0.15
func ContextWithAddr ¶ added in v1.0.15
func ContextWithAuth ¶ added in v1.0.15
func ContextWithHandler ¶ added in v1.0.15
func ContextWithPathParams ¶ added in v1.0.15
func ContextWithPluginName ¶ added in v1.0.15
func ContextWithPrefix ¶ added in v1.0.15
func DumpContext ¶ added in v1.0.15
func GetPluginName ¶ added in v1.0.15
GetPluginName returns the plugin name from a file path
func NewProvider ¶ added in v1.0.15
func PluginPath ¶ added in v1.0.15
PluginPath returns absolute path to a plugin or empty string if it can't be located
Types ¶
type PluginUsageFunc ¶ added in v1.0.15
func GetPluginUsage ¶ added in v1.0.15
func GetPluginUsage(path string) (PluginUsageFunc, error)
GetPluginUsage returns the usage function for a plugin
Click to show internal directories.
Click to hide internal directories.