provider

package
v1.0.27 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 29, 2021 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

const (
	PluginFileExt = ".plugin"
)

Variables

This section is empty.

Functions

func ContextAddr added in v1.0.15

func ContextAddr(ctx context.Context) string

func ContextHandlerMiddleware added in v1.0.15

func ContextHandlerMiddleware(ctx context.Context) []string

func ContextHandlerPrefix added in v1.0.15

func ContextHandlerPrefix(ctx context.Context) string

func ContextHasPluginParent added in v1.0.15

func ContextHasPluginParent(ctx context.Context, v string) bool

func ContextParams added in v1.0.15

func ContextParams(ctx context.Context) []string

func ContextPath added in v1.0.15

func ContextPath(ctx context.Context) string

func ContextPluginName added in v1.0.15

func ContextPluginName(ctx context.Context) string

func ContextUser added in v1.0.15

func ContextUser(ctx context.Context) string

func ContextWithAddr added in v1.0.15

func ContextWithAddr(parent context.Context, addr string) context.Context

func ContextWithAuth added in v1.0.15

func ContextWithAuth(parent context.Context, user string, auth map[string]interface{}) context.Context

func ContextWithHandler added in v1.0.15

func ContextWithHandler(parent context.Context, handler config.Handler) context.Context

func ContextWithPathParams added in v1.0.15

func ContextWithPathParams(parent context.Context, path string, params []string) context.Context

func ContextWithPluginName added in v1.0.15

func ContextWithPluginName(ctx context.Context, name string) context.Context

func ContextWithPrefix added in v1.0.15

func ContextWithPrefix(ctx context.Context, prefix string) context.Context

func DumpContext added in v1.0.15

func DumpContext(ctx context.Context) string

func GetPluginName added in v1.0.15

func GetPluginName(path string) (string, error)

GetPluginName returns the plugin name from a file path

func NewProvider added in v1.0.15

func NewProvider(parent context.Context, basepath string, cfg *config.Config) (*provider, error)

func PluginPath added in v1.0.15

func PluginPath(basepath, path string) string

PluginPath returns absolute path to a plugin or empty string if it can't be located

Types

type PluginUsageFunc added in v1.0.15

type PluginUsageFunc func(io.Writer)

func GetPluginUsage added in v1.0.15

func GetPluginUsage(path string) (PluginUsageFunc, error)

GetPluginUsage returns the usage function for a plugin

Jump to